==> qtjambi-location-debuginfo-macos-5.15.17.jar: sources/QtJambiLocation/QPlaceUser_shell.cpp <==
#include <QtCore/QtGlobal>
#include <QtLocation/qplaceuser.h>
#include <QtCore/QVariant>

#include <QtJambi/QtJambiAPI>
#include <QtJambiLocation/hashes.h>

#include <QtJambi/RegistryAPI>
#include <QtJambi/Cast>

void deleter_QPlaceUser(void *ptr, bool isShell)
{
    QTJAMBI_NATIVE_METHOD_CALL("qtjambi_deleter for QPlaceUser")
    QPlaceUser *_ptr = reinterpret_cast<QPlaceUser *>(ptr);
    if(!isShell){
        QtJambiAPI::registerNonShellDeletion(ptr);
    }
    delete _ptr;
}

// emitting (writeConstructors)
// new QPlaceUser()
void __qt_construct_QPlaceUser_0(void* __qtjambi_ptr, JNIEnv* __jni_env, jobject __jni_object, jvalue* __java_arguments)
{
    QTJAMBI_NATIVE_METHOD_CALL("construct QPlaceUser()")
    Q_UNUSED(__java_arguments)
    QPlaceUser *__qt_this = new(__qtjambi_ptr) QPlaceUser();
    Q_UNUSED(__jni_object)
    Q_UNUSED(__jni_env)
    Q_UNUSED(__qt_this)
}

// new QPlaceUser(QPlaceUser)
void __qt_construct_QPlaceUser_1(void* __qtjambi_ptr, JNIEnv* __jni_env, jobject __jni_object, jvalue* __java_arguments)
{
    QTJAMBI_NATIVE_METHOD_CALL("construct QPlaceUser(QPlaceUser)")
    jobject other0 = __java_arguments[0].l;
    const QPlaceUser& __qt_other0 = qtjambi_cast<const QPlaceUser& >(__jni_env, other0);
    QPlaceUser *__qt_this = new(__qtjambi_ptr) QPlaceUser(__qt_other0);
    Q_UNUSED(__jni_object)
    Q_UNUSED(__qt_this)
}

// destruct QPlaceUser
void __qt_destruct_QPlaceUser(void* ptr)
{
    QTJAMBI_NATIVE_METHOD_CALL("destruct QPlaceUser")
    reinterpret_cast<QPlaceUser*>(ptr)->~QPlaceUser();
}

// emitting  (functionsInTargetLang writeFinalFunction)
// QPlaceUser::QPlaceUser()
extern "C" Q_DECL_EXPORT void JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_location_QPlaceUser_initialize_1native__Lio_qt_location_QPlaceUser_2)
(JNIEnv *__jni_env,
 jclass __jni_class,
 jobject __jni_object)
{
    QTJAMBI_NATIVE_METHOD_CALL("QPlaceUser::QPlaceUser()")
    QTJAMBI_TRY {
        QtJambiShell::initialize(__jni_env, __jni_class, __jni_object, &__qt_construct_QPlaceUser_0, sizeof(QPlaceUser), typeid(QPlaceUser), false, &deleter_QPlaceUser, nullptr);
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END

}

// QPlaceUser::QPlaceUser(QPlaceUser)
extern "C" Q_DECL_EXPORT void JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_location_QPlaceUser_initialize_1native__Lio_qt_location_QPlaceUser_2Lio_qt_location_QPlaceUser_2)
(JNIEnv *__jni_env,
 jclass __jni_class,
 jobject __jni_object,
 jobject other0)
{
    QTJAMBI_NATIVE_METHOD_CALL("QPlaceUser::QPlaceUser(QPlaceUser)")
    QTJAMBI_TRY {
        jvalue arguments;
        arguments.l = other0;
        QtJambiShell::initialize(__jni_env, __jni_class, __jni_object, &__qt_construct_QPlaceUser_1, sizeof(QPlaceUser), typeid(QPlaceUser), false, &deleter_QPlaceUser, &arguments);
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END

}

// QPlaceUser::name()const
extern "C" Q_DECL_EXPORT jstring JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_location_QPlaceUser_name_1native_1constfct__J)
(JNIEnv *__jni_env,
 jobject __this,
 QtJambiNativeID __this_nativeId)
{
    Q_UNUSED(__this)
    jstring __java_return_value{0};
    QTJAMBI_TRY {
        const QPlaceUser *__qt_this = QtJambiAPI::objectFromNativeId<QPlaceUser>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        QTJAMBI_NATIVE_INSTANCE_METHOD_CALL("QPlaceUser::name()const", __qt_this)
        QString __qt_return_value = __qt_this->name();
        __java_return_value = qtjambi_cast<jstring>(__jni_env, __qt_return_value);
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END
    return __java_return_value;

}

// QPlaceUser::operator=(QPlaceUser)
extern "C" Q_DECL_EXPORT void JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_location_QPlaceUser_assign_1native_1cref_1QPlaceUser__JJ)
(JNIEnv *__jni_env,
 jobject __this,
 QtJambiNativeID __this_nativeId,
 QtJambiNativeID other0)
{
    Q_UNUSED(__this)
    QTJAMBI_TRY {
        QPlaceUser *__qt_this = QtJambiAPI::objectFromNativeId<QPlaceUser>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        QTJAMBI_NATIVE_INSTANCE_METHOD_CALL("QPlaceUser::operator=(QPlaceUser)", __qt_this)
        const QPlaceUser& __qt_other0 = QtJambiAPI::valueReferenceFromNativeId<QPlaceUser>(other0);
        (*__qt_this) = __qt_other0;
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END

}

// QPlaceUser::operator==(QPlaceUser)const
extern "C" Q_DECL_EXPORT jboolean JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_location_QPlaceUser_operator_1equal_1native_1cref_1QPlaceUser_1constfct__JJ)
(JNIEnv *__jni_env,
 jobject __this,
 QtJambiNativeID __this_nativeId,
 QtJambiNativeID other0)
{
    Q_UNUSED(__this)
    jboolean __java_return_value{0};
    QTJAMBI_TRY {
        const QPlaceUser *__qt_this = QtJambiAPI::objectFromNativeId<QPlaceUser>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        QTJAMBI_NATIVE_INSTANCE_METHOD_CALL("QPlaceUser::operator==(QPlaceUser)const", __qt_this)
        const QPlaceUser& __qt_other0 = QtJambiAPI::valueReferenceFromNativeId<QPlaceUser>(other0);
        __java_return_value = (*__qt_this) == __qt_other0;
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END
    return __java_return_value;

}

// QPlaceUser::setName(QString)
extern "C" Q_DECL_EXPORT void JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_location_QPlaceUser_setName_1native_1cref_1QString__JLjava_lang_String_2)
(JNIEnv *__jni_env,
 jobject __this,
 QtJambiNativeID __this_nativeId,
 jstring name0)
{
    Q_UNUSED(__this)
    QTJAMBI_TRY {
        QPlaceUser *__qt_this = QtJambiAPI::objectFromNativeId<QPlaceUser>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        QTJAMBI_NATIVE_INSTANCE_METHOD_CALL("QPlaceUser::setName(QString)", __qt_this)
        QString  __qt_name0 = qtjambi_cast<QString >(__jni_env, name0);
        __qt_this->setName(__qt_name0);
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END

}

// QPlaceUser::setUserId(QString)
extern "C" Q_DECL_EXPORT void JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_location_QPlaceUser_setUserId_1native_1cref_1QString__JLjava_lang_String_2)
(JNIEnv *__jni_env,
 jobject __this,
 QtJambiNativeID __this_nativeId,
 jstring identifier0)
{
    Q_UNUSED(__this)
    QTJAMBI_TRY {
        QPlaceUser *__qt_this = QtJambiAPI::objectFromNativeId<QPlaceUser>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        QTJAMBI_NATIVE_INSTANCE_METHOD_CALL("QPlaceUser::setUserId(QString)", __qt_this)
        QString  __qt_identifier0 = qtjambi_cast<QString >(__jni_env, identifier0);
        __qt_this->setUserId(__qt_identifier0);
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END

}

// QPlaceUser::userId()const
extern "C" Q_DECL_EXPORT jstring JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_location_QPlaceUser_userId_1native_1constfct__J)
(JNIEnv *__jni_env,
 jobject __this,
 QtJambiNativeID __this_nativeId)
{
    Q_UNUSED(__this)
    jstring __java_return_value{0};
    QTJAMBI_TRY {
        const QPlaceUser *__qt_this = QtJambiAPI::objectFromNativeId<QPlaceUser>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        QTJAMBI_NATIVE_INSTANCE_METHOD_CALL("QPlaceUser::userId()const", __qt_this)
        QString __qt_return_value = __qt_this->userId();
        __java_return_value = qtjambi_cast<jstring>(__jni_env, __qt_return_value);
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END
    return __java_return_value;

}

// emitting (writeJavaLangObjectOverrideFunctions)

extern "C" Q_DECL_EXPORT jint JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_location_QPlaceUser_hashCode_1native)
(JNIEnv * __jni_env, jclass, QtJambiNativeID __this_nativeId)
{
    jint __java_return_value = 0;
    QTJAMBI_TRY {
        QPlaceUser *__qt_this = QtJambiAPI::objectFromNativeId<QPlaceUser>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        hash_type hashValue = qHash(*__qt_this);
        __java_return_value = jint(hashValue);
    } QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    } QTJAMBI_TRY_END
    return __java_return_value;
}
// emitting (writeCloneFunction)

extern "C" Q_DECL_EXPORT jobject JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_location_QPlaceUser_clone_1native)
(JNIEnv *__jni_env, jobject, QtJambiNativeID __this_nativeId)
{
    jobject __java_return_value = nullptr;
    QTJAMBI_TRY {
        const QPlaceUser *__qt_this = QtJambiAPI::objectFromNativeId<QPlaceUser>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        __java_return_value = qtjambi_cast<jobject>(__jni_env, *__qt_this);
    } QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    } QTJAMBI_TRY_END
    return __java_return_value;
}


void initialize_meta_info_QPlaceUser(){
    using namespace RegistryAPI;
    const std::type_info& typeId = registerValueTypeInfo<QPlaceUser>("QPlaceUser", "io/qt/location/QPlaceUser");
    Q_UNUSED(typeId)
// BEGIN: function table
    registerConstructorInfos(typeId, &__qt_destruct_QPlaceUser, {
        ConstructorInfo(&__qt_construct_QPlaceUser_0, nullptr)
       ,ConstructorInfo(&__qt_construct_QPlaceUser_1, "Lio/qt/location/QPlaceUser;")
    });
// END: function table

// BEGIN: type registration
    registerDeleter(typeId, &deleter_QPlaceUser);
    registerMetaType<QPlaceUser>("QPlaceUser");
// END: type registration

// BEGIN: polymorphic ids
// END: polymorphic ids


// BEGIN: enums and flags
// END: enums and flags
}

==> qtjambi-location-debuginfo-macos-5.15.20.jar: sources/QtJambiLocation/QPlaceUser_shell.cpp <==
#include <QtCore/QtGlobal>
#include <QtLocation/qplaceuser.h>
#include <QtCore/QVariant>

#include <QtJambi/QtJambiAPI>
#include <QtJambiLocation/hashes.h>

#include <QtJambi/RegistryAPI>
#include <QtJambi/Cast>

void deleter_QPlaceUser(void *ptr, bool isShell)
{
    QTJAMBI_NATIVE_METHOD_CALL("qtjambi_deleter for QPlaceUser")
    QPlaceUser *_ptr = reinterpret_cast<QPlaceUser *>(ptr);
    if(!isShell){
        QtJambiAPI::registerNonShellDeletion(ptr);
    }
    delete _ptr;
}

// emitting (writeConstructors)
// new QPlaceUser()
void __qt_construct_QPlaceUser(void* __qtjambi_ptr, JNIEnv* __jni_env, jobject __jni_object, jvalue* __java_arguments, bool __qtjambi_is_generic)
{
    QTJAMBI_NATIVE_METHOD_CALL("construct QPlaceUser()")
    Q_UNUSED(__java_arguments)
    QPlaceUser *__qt_this = new(__qtjambi_ptr) QPlaceUser();
    Q_UNUSED(__qtjambi_is_generic)
    Q_UNUSED(__jni_object)
    Q_UNUSED(__jni_env)
    Q_UNUSED(__qt_this)
}

// QPlaceUser::QPlaceUser()
extern "C" Q_DECL_EXPORT void JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_location_QPlaceUser_initialize_1native__Lio_qt_location_QPlaceUser_2)
(JNIEnv *__jni_env,
 jclass __jni_class,
 jobject __jni_object)
{
    QTJAMBI_NATIVE_METHOD_CALL("QPlaceUser::QPlaceUser()")
    QTJAMBI_TRY {
        QtJambiShell::initialize(__jni_env, __jni_class, __jni_object, &__qt_construct_QPlaceUser, sizeof(QPlaceUser), typeid(QPlaceUser), false, &deleter_QPlaceUser, nullptr);
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END

}

// new QPlaceUser(QPlaceUser)
void __qt_construct_QPlaceUser_cref_QPlaceUser(void* __qtjambi_ptr, JNIEnv* __jni_env, jobject __jni_object, jvalue* __java_arguments, bool __qtjambi_is_generic)
{
    QTJAMBI_NATIVE_METHOD_CALL("construct QPlaceUser(QPlaceUser)")
    jobject other0 = __java_arguments[0].l;
    const QPlaceUser& __qt_other0 = qtjambi_cast<const QPlaceUser& >(__jni_env, other0);
    QPlaceUser *__qt_this = new(__qtjambi_ptr) QPlaceUser(__qt_other0);
    Q_UNUSED(__qtjambi_is_generic)
    Q_UNUSED(__jni_object)
    Q_UNUSED(__qt_this)
}

// QPlaceUser::QPlaceUser(QPlaceUser)
extern "C" Q_DECL_EXPORT void JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_location_QPlaceUser_initialize_1native__Lio_qt_location_QPlaceUser_2Lio_qt_location_QPlaceUser_2)
(JNIEnv *__jni_env,
 jclass __jni_class,
 jobject __jni_object,
 jobject other0)
{
    QTJAMBI_NATIVE_METHOD_CALL("QPlaceUser::QPlaceUser(QPlaceUser)")
    QTJAMBI_TRY {
        jvalue arguments;
        arguments.l = other0;
        QtJambiShell::initialize(__jni_env, __jni_class, __jni_object, &__qt_construct_QPlaceUser_cref_QPlaceUser, sizeof(QPlaceUser), typeid(QPlaceUser), false, &deleter_QPlaceUser, &arguments);
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END

}

// destruct QPlaceUser
void __qt_destruct_QPlaceUser(void* ptr)
{
    QTJAMBI_NATIVE_METHOD_CALL("destruct QPlaceUser")
    reinterpret_cast<QPlaceUser*>(ptr)->~QPlaceUser();
}

// emitting  (functionsInTargetLang writeFinalFunction)
// QPlaceUser::name()const
extern "C" Q_DECL_EXPORT jstring JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_location_QPlaceUser_name_1native_1constfct__J)
(JNIEnv *__jni_env,
 jobject __this,
 QtJambiNativeID __this_nativeId)
{
    Q_UNUSED(__this)
    jstring __java_return_value{0};
    QTJAMBI_TRY {
        const QPlaceUser *__qt_this = QtJambiAPI::objectFromNativeId<QPlaceUser>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        QTJAMBI_NATIVE_INSTANCE_METHOD_CALL("QPlaceUser::name()const", __qt_this)
        QString __qt_return_value = __qt_this->name();
        __java_return_value = qtjambi_cast<jstring>(__jni_env, __qt_return_value);
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END
    return __java_return_value;

}

// QPlaceUser::operator=(QPlaceUser)
extern "C" Q_DECL_EXPORT void JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_location_QPlaceUser_assign_1native_1cref_1QPlaceUser__JJ)
(JNIEnv *__jni_env,
 jobject __this,
 QtJambiNativeID __this_nativeId,
 QtJambiNativeID other0)
{
    Q_UNUSED(__this)
    QTJAMBI_TRY {
        QPlaceUser *__qt_this = QtJambiAPI::objectFromNativeId<QPlaceUser>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        QTJAMBI_NATIVE_INSTANCE_METHOD_CALL("QPlaceUser::operator=(QPlaceUser)", __qt_this)
        const QPlaceUser& __qt_other0 = QtJambiAPI::valueReferenceFromNativeId<QPlaceUser>(other0);
        (*__qt_this) = __qt_other0;
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END

}

// QPlaceUser::operator==(QPlaceUser)const
extern "C" Q_DECL_EXPORT jboolean JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_location_QPlaceUser_equals_1native_1cref_1QPlaceUser_1constfct__JJ)
(JNIEnv *__jni_env,
 jobject __this,
 QtJambiNativeID __this_nativeId,
 QtJambiNativeID other0)
{
    Q_UNUSED(__this)
    jboolean __java_return_value{0};
    QTJAMBI_TRY {
        const QPlaceUser *__qt_this = QtJambiAPI::objectFromNativeId<QPlaceUser>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        QTJAMBI_NATIVE_INSTANCE_METHOD_CALL("QPlaceUser::operator==(QPlaceUser)const", __qt_this)
        const QPlaceUser& __qt_other0 = QtJambiAPI::valueReferenceFromNativeId<QPlaceUser>(other0);
        __java_return_value = (*__qt_this) == __qt_other0;
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END
    return __java_return_value;

}

// QPlaceUser::setName(QString)
extern "C" Q_DECL_EXPORT void JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_location_QPlaceUser_setName_1native_1cref_1QString__JLjava_lang_String_2)
(JNIEnv *__jni_env,
 jobject __this,
 QtJambiNativeID __this_nativeId,
 jstring name0)
{
    Q_UNUSED(__this)
    QTJAMBI_TRY {
        QPlaceUser *__qt_this = QtJambiAPI::objectFromNativeId<QPlaceUser>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        QTJAMBI_NATIVE_INSTANCE_METHOD_CALL("QPlaceUser::setName(QString)", __qt_this)
        QString  __qt_name0 = qtjambi_cast<QString>(__jni_env, name0);
        __qt_this->setName(__qt_name0);
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END

}

// QPlaceUser::setUserId(QString)
extern "C" Q_DECL_EXPORT void JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_location_QPlaceUser_setUserId_1native_1cref_1QString__JLjava_lang_String_2)
(JNIEnv *__jni_env,
 jobject __this,
 QtJambiNativeID __this_nativeId,
 jstring identifier0)
{
    Q_UNUSED(__this)
    QTJAMBI_TRY {
        QPlaceUser *__qt_this = QtJambiAPI::objectFromNativeId<QPlaceUser>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        QTJAMBI_NATIVE_INSTANCE_METHOD_CALL("QPlaceUser::setUserId(QString)", __qt_this)
        QString  __qt_identifier0 = qtjambi_cast<QString>(__jni_env, identifier0);
        __qt_this->setUserId(__qt_identifier0);
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END

}

// QPlaceUser::userId()const
extern "C" Q_DECL_EXPORT jstring JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_location_QPlaceUser_userId_1native_1constfct__J)
(JNIEnv *__jni_env,
 jobject __this,
 QtJambiNativeID __this_nativeId)
{
    Q_UNUSED(__this)
    jstring __java_return_value{0};
    QTJAMBI_TRY {
        const QPlaceUser *__qt_this = QtJambiAPI::objectFromNativeId<QPlaceUser>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        QTJAMBI_NATIVE_INSTANCE_METHOD_CALL("QPlaceUser::userId()const", __qt_this)
        QString __qt_return_value = __qt_this->userId();
        __java_return_value = qtjambi_cast<jstring>(__jni_env, __qt_return_value);
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END
    return __java_return_value;

}

// emitting (writeJavaLangObjectOverrideFunctions)

extern "C" Q_DECL_EXPORT jint JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_location_QPlaceUser_hashCode_1native)
(JNIEnv * __jni_env, jclass, QtJambiNativeID __this_nativeId)
{
    jint __java_return_value = 0;
    QTJAMBI_TRY {
        QPlaceUser *__qt_this = QtJambiAPI::objectFromNativeId<QPlaceUser>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        hash_type hashValue = qHash(*__qt_this);
        __java_return_value = jint(hashValue);
    } QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    } QTJAMBI_TRY_END
    return __java_return_value;
}
// emitting (writeCloneFunction)

extern "C" Q_DECL_EXPORT jobject JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_location_QPlaceUser_clone_1native)
(JNIEnv *__jni_env, jobject, QtJambiNativeID __this_nativeId)
{
    jobject __java_return_value = nullptr;
    QTJAMBI_TRY {
        const QPlaceUser *__qt_this = QtJambiAPI::objectFromNativeId<QPlaceUser>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        __java_return_value = qtjambi_cast<jobject>(__jni_env, *__qt_this);
    } QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    } QTJAMBI_TRY_END
    return __java_return_value;
}


void initialize_meta_info_QPlaceUser(){
    using namespace RegistryAPI;
    const std::type_info& typeId = registerValueTypeInfo<QPlaceUser>("QPlaceUser", "io/qt/location/QPlaceUser");
    Q_UNUSED(typeId)
// BEGIN: function table
    registerConstructorInfos(typeId, &__qt_destruct_QPlaceUser, {
        ConstructorInfo(&__qt_construct_QPlaceUser, nullptr)
       ,ConstructorInfo(&__qt_construct_QPlaceUser_cref_QPlaceUser, "Lio/qt/location/QPlaceUser;")
    });
// END: function table

// BEGIN: type registration
    registerDeleter(typeId, &deleter_QPlaceUser);
    registerMetaType<QPlaceUser>("QPlaceUser");
// END: type registration

// BEGIN: polymorphic ids
// END: polymorphic ids


// BEGIN: enums and flags
// END: enums and flags
}
